@@ -6,19 +6,29 @@
 #include <KNSCore/Entry>
 #include <QAbstractListModel>
 #include <keduvocdocument.h>
+#include <qqmlintegration.h>
 
 /// @author Carl Schwan <carl@carlschwan.eu>
 class KWQDocumentModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(DocumentModel)
 
 public:
     enum ExtraRoles {
         TitleRole = Qt::UserRole + 1,
         UrlRole,
         DocumentRole,
+        DocumentStatusRole,
     };
 
+    enum class DocumentStatus {
+        NoError,
+        CannotLoadFile,
+        CannotSaveFile,
+    };
+    Q_ENUM(DocumentStatus)
+
     explicit KWQDocumentModel(QObject *parent = nullptr);
     ~KWQDocumentModel();
 
@@ -36,5 +46,5 @@ public:
     Q_INVOKABLE void entryChanged(const KNSCore::Entry &wrapper);
 
 private:
-    std::vector<std::unique_ptr<KEduVocDocument>> m_documents;
+    std::vector<std::pair<std::unique_ptr<KEduVocDocument>, DocumentStatus>> m_documents;
 };
